import pytest
from abstract_open_traffic_generator import *


def test_connect():
    # api = Api()
    # try:
    #     api.connect()
    #     assert('Incorrect behavior')
    # except NotImplementedError:
    #     pass
    pass


def test_sate_config():
    # api = Api()
    # config = Config()
    # try:
    #     api.control(payload=config)
    #     assert('Incorrect behavior')
    # except NotImplementedError:
    #     pass
    pass


if __name__ == '__main__':
    pytest.main(['-s', __file__])
